@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 4157 2011-05-27 13:33:45Z fishbone $
+ * @version    SVN: $Id: envManager.php 4298 2011-09-06 03:02:06Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -961,11 +961,16 @@ class EnvManager extends Core
 	 */
 	public function isAdminDirAccess()
 	{
-		if (dirname($this->getCurrentScriptPath()) == $this->getAdminPath()){
-			return true;
-		} else {
-			return false;
+		static $isAdminDirAccess;
+		
+		if (!isset($isAdminDirAccess)){
+			if (dirname($this->getCurrentScriptPath()) == $this->getAdminPath()){
+				$isAdminDirAccess = true;
+			} else {
+				$isAdminDirAccess = false;
+			}
 		}
+		return $isAdminDirAccess;
 	}
 	// ##################### カレントのテンプレート関係 #####################
 	/**
@@ -1371,6 +1376,68 @@ class EnvManager extends Core
 			return $userInfo->userType;
 		}
 	}
+	/**
+	 * 現在のユーザがアクセス可能なウィジェットを取得
+	 *
+	 * @return array		ウィジェット
+	 */
+/*	public function getAccessableWidget()
+	{
+		global $gInstanceManager;
+
+		$userInfo = $gInstanceManager->getUserInfo();
+		if (is_null($userInfo)){		// ログインしていない場合
+			return array();
+		} else {
+			return $userInfo->adminWidget;
+		}
+	}*/
+	/**
+	 * 現在のユーザが指定のウィジェットの管理画面が使用可能かを取得
+	 *
+	 * @param string $widgetId	ウィジェットID
+	 * @return bool				true=使用可能、false=使用不可
+	 */
+	public function canUseWidgetAdmin($widgetId)
+	{
+		global $gInstanceManager;
+
+		$canUseAdmin = false;
+		$userInfo = $gInstanceManager->getUserInfo();
+		if (!is_null($userInfo)){		// ログイン中の場合
+			if ($userInfo->userType == UserInfo::USER_TYPE_SYS_ADMIN){	// システム管理者の場合
+				$canUseAdmin = true;
+			} else if ($userInfo->userType == UserInfo::USER_TYPE_MANAGER){	// システム運用者の場合
+				$accessWidget = $userInfo->adminWidget;
+				if (empty($accessWidget)){
+					$canUseAdmin = true;
+				} else {
+					if (in_array($widgetId, $accessWidget)) $canUseAdmin = true;
+				}
+			}
+		}
+		return $canUseAdmin;
+	}
+	/**
+	 * 現在のユーザがユーザタイプオプションを持っているかを取得
+	 *
+	 * @param string $option	ユーザタイプオプション
+	 * @return bool				true=オプションあり、false=オプションなし
+	 */
+	public function hasUserTypeOption($option)
+	{
+		global $gInstanceManager;
+
+		$hasOption = false;
+		$userInfo = $gInstanceManager->getUserInfo();
+		if (!is_null($userInfo)){		// ログイン中の場合
+			if ($userInfo->userType == UserInfo::USER_TYPE_MANAGER){	// システム運用者の場合
+				$pos = strpos($userInfo->userTypeOption, $option);
+				if ($pos !== false) $hasOption = true;
+			}
+		}
+		return $hasOption;
+	}
 	/**
 	 * 管理者用一時キーを取得
 	 *
