@@ -1,6 +1,6 @@
 <?php
 /**
- * @version		$Id: factory.php 3974 2011-01-31 07:56:03Z fishbone $
+ * @version		$Id: factory.php 4421 2011-11-07 03:07:40Z fishbone $
  * @package		Joomla.Framework
  * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
  * @license		GNU/GPL, see LICENSE.php
@@ -38,13 +38,17 @@ class JFactory
 		if (!is_object($instance))
 		{
 //			jimport( 'joomla.application.application' );
+			global $gEnvManager;
 
+			// JApplicationクラスを読み込む
+			require_once($gEnvManager->getJoomlaRootPath() . '/class/application.php');
+			
 /*			if (!$id) {
 				JError::raiseError(500, 'Application Instantiation Error');
-			}
+			}*/
 
 			$instance = JApplication::getInstance($id, $config, $prefix);
-			*/
+//			$instance = new JApplication();
 		}
 
 		return $instance;
