@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_base.sql 4173 2011-06-08 09:14:43Z fishbone $
+-- * @version    SVN: $Id: create_base.sql 4313 2011-09-12 12:27:04Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -186,7 +186,9 @@ CREATE TABLE _login_user (
     lu_password          CHAR(32)       DEFAULT ''                    NOT NULL,      -- ログインパスワード(MD5)
     lu_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
     lu_user_type         SMALLINT       DEFAULT 0                     NOT NULL,      -- ユーザタイプ(-1=未承認ユーザ、0=仮ユーザ、10=一般ユーザ、50=システム運営者、100=システム管理者)
+    lu_user_type_option  TEXT                                         NOT NULL,      -- ユーザタイプオプション(「ウィジェットID=ユーザタイプ」形式の前後「;」区切りで複数指定可)
     lu_assign            TEXT                                         NOT NULL,      -- ログイン可能な機能(2バイト文字カンマ区切り、sy=システム管理機能、ec=EC、bg=ブログ、bs=BBS、rv=予約, wk=Wiki)
+    lu_admin_widget      TEXT                                         NOT NULL,      -- システム運営者が管理可能なウィジェット(「,」区切りで複数指定可)
     lu_user_status       SMALLINT       DEFAULT 0                     NOT NULL,      -- ユーザの状態
     lu_avatar            VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アバターファイル名
     lu_enable_login      BOOLEAN        DEFAULT true                  NOT NULL,      -- ログイン許可
@@ -414,6 +416,7 @@ CREATE TABLE _widgets (
     wd_author            VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 作者名
     wd_copyright         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 著作権
     wd_license           VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- ライセンス
+    wd_license_type      INT            DEFAULT 0                     NOT NULL,      -- ライセンスタイプ(0=オープンソース、1=商用)
     wd_official_level    INT            DEFAULT 0                     NOT NULL,      -- 公認レベル(0=非公認、1=準公認、10=正規公認)
     wd_status            INT            DEFAULT 0                     NOT NULL,      -- 状態(0=通常,1=テスト中,-1=廃止予定,-10=廃止)
     wd_cache_type        INT            DEFAULT 0                     NOT NULL,      -- キャッシュタイプ(0=不可、1=可、2=非ログイン時可, 3=ページキャッシュのみ可)
