@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 4313 2011-09-12 12:27:04Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 4357 2011-09-26 03:04:11Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -158,7 +158,7 @@ INSERT INTO _page_id
 ('blog',         1,       '',                '',            'ブログ',                           'ブログ画面用',                       5,           0,              true,      true,      false,     true),
 ('wiki',         1,       '',                '',            'Wiki',                             'Wiki画面用',                         6,           0,              true,      true,      false,     true),
 ('event',        1,       '',                '',            'イベント',                         'イベント画面用',                     7,           0,              true,      true,      false,     true),
-('photo',        1,       '',                '',            'フォトアルバム',                   'フォトアルバム画面用',               8,           0,              true,      true,      false,     true),
+('photo',        1,       '',                '',            'フォトギャラリー',                   'フォトギャラリー画面用',               8,           0,              true,      true,      false,     true),
 ('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 9,           0,              true,      true,      false,     true),
 ('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 10,          0,              true,      true,      false,     true),
 ('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 11,          0,              true,      true,      false,     true),
