@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: _develop.sql 4396 2011-10-15 00:09:22Z fishbone $
+-- * @version    SVN: $Id: _develop.sql 4432 2011-11-08 06:03:12Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [開発ウィジェット登録]   *****仕様変更あり注意*****
@@ -19,17 +19,38 @@
 DELETE FROM _widgets WHERE wd_id = 'photo_cart';
 INSERT INTO _widgets 
 (wd_id,        wd_name,                     wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_has_admin, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
-('photo_cart', 'フォトギャラリー - カート', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                'フォトギャラリーでカート内の商品を表示するボックス。',   false,    true,           100, 0, 0, now(),      now());
+('photo_cart', 'フォトギャラリー - カート', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                'フォトギャラリーのカート内の商品を表示するオプションウィジェット。',   false,    true,           100, 0, 0, now(),      now());
+DELETE FROM _widgets WHERE wd_id = 'photo_shop';
+INSERT INTO _widgets
+(wd_id,     wd_name,              wd_version, wd_author,      wd_copyright, wd_license, wd_license_type, wd_official_level, wd_description,                                                        wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
+('photo_shop', 'フォトギャラリー - ショップ', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License',   1,   10,                'フォトギャラリーの商品購入オプションウィジェット。', true,         true,   0, 2, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'photo_login';
+INSERT INTO _widgets
+(wd_id,         wd_name,                       wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_add_script_lib, wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
+('photo_login', 'フォトギャラリー - ログイン', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10, 'フォトギャラリーの会員ログイン用ボックス。', 'md5',     false,     true,           2, -1, now(), now());
+
+-- インナーウィジェット
+ALTER TABLE _iwidgets ADD iw_license_type    INT            DEFAULT 0                     NOT NULL;      -- ライセンスタイプ(0=オープンソース、1=商用)
+DELETE FROM _iwidgets WHERE iw_widget_id = 'photo_shop' AND iw_id = 'epsilon';
+INSERT INTO _iwidgets
+(iw_widget_id, iw_id,     iw_name,          iw_type,    iw_author,      iw_copyright, iw_license,               iw_license_type, iw_official_level, iw_install_dt, iw_create_dt) VALUES
+('photo_shop', 'epsilon', 'イプシロン決済', 'PAYMENT', 'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                now(),         now());
 
 -- フォトギャラリー設定マスター
 INSERT INTO photo_config
 (hg_id,               hg_value,           hg_name,                                  hg_index) VALUES
-('online_shop',       '1',                'オンラインショップ機能',                             12);
+('online_shop',       '1',                'オンラインショップ機能',                 12),
+('use_email',         '1',                'メール送信機能',                         13),
+('shop_email',        '',                 'ショップ宛てメールアドレス',             14),
+('auto_email_sender', '',                 '自動送信メール送信元アドレス',           15),
+('use_member_address', '0',               '会員登録の住所使用',                     16);
 
 -- *** Eコマーステーブル ***
 -- 受注明細トラン
+ALTER TABLE order_detail MODIFY od_product_name     TEXT NOT NULL;       -- 商品名
 ALTER TABLE order_detail ADD od_product_class     VARCHAR(10)    DEFAULT ''                    NOT NULL;      -- 商品クラス
 ALTER TABLE order_detail ADD od_product_type_id   VARCHAR(10)    DEFAULT ''                    NOT NULL;      -- 商品タイプ
+ALTER TABLE order_detail ADD od_product_code     TEXT NOT NULL;       -- 商品コード
 
 -- 商品タイプマスター
 DROP TABLE IF EXISTS product_type;
@@ -41,8 +62,16 @@ CREATE TABLE product_type (
     py_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
     py_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 名称
+    py_code              VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプコード
     py_description       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 説明
     py_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
+    py_single_select     BOOLEAN        DEFAULT false                 NOT NULL,      -- 単数選択のみ
+
+    py_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    py_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    py_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    py_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    py_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (py_serial),
     UNIQUE               (py_product_class,     py_id,        py_language_id,               py_history_index)
 ) TYPE=innodb;
@@ -61,8 +90,8 @@ ALTER TABLE shop_cart_item ADD UNIQUE (si_head_serial, si_product_class,     si_
 
 -- 商品タイプマスター
 INSERT INTO product_type
-(py_product_class, py_id,      py_language_id, py_name,            py_description, py_index) VALUES 
-('photo',          'download', 'ja',           'ダウンロード購入', '',             1);
+(py_product_class, py_id,      py_language_id, py_name,            py_code, py_description, py_index, py_single_select) VALUES 
+('photo',          'download', 'ja',           'ダウンロード画像', 'DL',    '',             1,        true);
 
 -- 商品価格マスター
 INSERT INTO product_price
