@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 3884 2010-12-08 03:05:00Z fishbone $
+ * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 4257 2011-08-22 05:22:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -152,6 +152,8 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 			$localeText['label_menu_layout'] = $this->_('Menu Layout');		// メニューレイアウト
 			$localeText['msg_change_item_order'] = $this->_('Menu items can be sorted by mouse drag and drop.');		// マウスドラッグで項目の表示順を変更できます
 			$localeText['label_menu_top'] = $this->_('Menu Top');					// メニュートップ
+			$localeText['label_open_all'] = $this->_('Open All');					// すべて開く
+			$localeText['label_close_all'] = $this->_('Close All');				// すべて閉じる
 		}
 		$this->setLocaleText($localeText);
 	}
@@ -236,6 +238,9 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar('_widget', 'content_widget_id', self::CONTENT_WIDGET_ID);// コンテンツ表示ウィジェット
 		$this->tmpl->addVar('_widget', 'admin_url', $this->getUrl($this->gEnv->getDefaultAdminUrl()));// 管理者URL
 		$this->tmpl->addVar("_widget", "fixed_mode", $fixedMode);		// メニュー定義IDが固定かどうか
+		
+		// ディレクトリを設定
+		$this->tmpl->addVar("_widget", "script_url", $this->getUrl($this->gEnv->getScriptsUrl()));
 	}
 	/**
 	 * 詳細画面作成
@@ -783,18 +788,18 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 				
 				// ##### ツリーメニュー作成 #####
 				if ($row['md_type'] == 0){	// リンク項目のとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . $this->convertToDispString($row['md_name']) . '</span></li>' . M3_NL;
+					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><a href="#">' . $this->convertToDispString($row['md_name']) . '</a></li>' . M3_NL;
 				} else if ($row['md_type'] == 1){			// フォルダのとき
 					// サブメニュー作成
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . $this->convertToDispString($row['md_name']) . '</span>' . M3_NL;
+					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '" rel="folder" class="jstree-open"><a href="#">' . $this->convertToDispString($row['md_name']) . '</a>' . M3_NL;
 					$treeHtml .= '<ul>' . M3_NL;
 					$treeHtml .= $this->createTreeMenu($menuId, $row['md_id'], $level + 1);
 					$treeHtml .= '</ul>' . M3_NL;
 					$treeHtml .= '</li>' . M3_NL;
 				} else if ($row['md_type'] == 2){			// テキストのとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . $this->convertToDispString($row['md_name']) . '</span></li>' . M3_NL;
+					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><a href="#">' . $this->convertToDispString($row['md_name']) . '</a></li>' . M3_NL;
 				} else if ($row['md_type'] == 3){			// セパレータのとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . '-----' . '</span></li>' . M3_NL;
+					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><a href="#">' . '-----' . '</a></li>' . M3_NL;
 				}
 			}
 		}
