@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 4223 2011-07-08 03:56:33Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 4295 2011-09-06 02:46:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -118,7 +118,7 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 		// 直接実行の場合
 		if($cmd == M3_REQUEST_CMD_DO_WIDGET){		// ウィジェット単体実行
 			// 管理者権限がなければ実行できない
-			if ($this->gEnv->isSystemAdmin() || $this->gAccess->isValidAdminKey($request)){
+			if ($this->gEnv->isSystemAdmin()){
 				// コンテナを起動
 				$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
 				switch ($task){
