@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4399 2011-10-17 00:47:53Z fishbone $
+ * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4411 2011-10-20 04:23:14Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -53,7 +53,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	const NEXT_BUTTON_TITLE = '次へ';		// 「次へ」ボタンタイトル
 	const SEARCH_FIELD_HEAD = 'photo_main_item';			// フィールド名の先頭文字列
 	const SEARCH_FIELD_CLASS_HEAD = 'photo_main_';			// フィールドクラスの先頭文字列
-	const TARGET_WIDGET = 'photo_ec_main';			// 画像購入ウィジェット
+	const TARGET_WIDGET = 'photo_shop';			// 画像購入ウィジェット
 	const PRODUCT_CLASS = 'photo';			// 商品クラス
 	const TAX_TYPE = 'sales';						// 課税タイプ(外税)
 	const PRODUCT_TYPE_DOWNLOAD = 'download';		// 商品タイプ
@@ -305,7 +305,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	{
 		$commentDb = new photo_commentDb();
 		
-		$ret = self::$_mainDb->getSearchPhotoInfo($this->photoId, $row, $categoryRows);
+		$ret = self::$_mainDb->getSearchPhotoInfo($this->photoId, $this->_langId, $row, $categoryRows);
 		if ($ret){
 			// URLパラメータ
 			$itemNo = $request->trimValueOf(M3_REQUEST_PARAM_ITEM_NO);		// 画像No
@@ -342,7 +342,13 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 				$width = $height = photo_mainCommonDef::DEFAULT_PUBLIC_IMAGE_SIZE;
 			}
 			
-			$imageUrl = photo_mainCommonDef::getPublicImageUrl($this->photoId);
+			// 詳細画像
+			$imagePath = photo_mainCommonDef::getPublicImagePath($this->photoId);
+			if (file_exists($imagePath)){
+				$imageUrl = photo_mainCommonDef::getPublicImageUrl($this->photoId);
+			} else {
+				$imageUrl = $this->notfoundThumbnailUrl;
+			}
 			
 			// パーマリンク
 			$permaUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_PHOTO_ID . '=' . $this->photoId);
@@ -488,7 +494,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$quantity = $request->trimIntValueOf('quantity', '1');		// 数量
 
 		// パラメータエラーチェック
-		if (!$this->isPublicPhotoId($this->photoId)) return;		// 画像が非公開の場合は終了
+		if (!$this->isPublicPhotoId($this->photoId, $this->_langId)) return;		// 画像が非公開の場合は終了
 		
 		// クッキー読み込み、カートIDを取得
 		$cartId = $request->getCookieValue(M3_COOKIE_CART_ID);
@@ -522,6 +528,8 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$ecLibObj->setTaxType($taxType, $this->_langId);		// 税種別設定
 			$totalPrice = $ecLibObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 		} else {		// 商品情報が取得できないときは、カートの商品をキャンセル
+			$this->writeError(__METHOD__, '商品情報が取得できません。', 1100,
+													'商品クラス=' . self::PRODUCT_CLASS . ', 画像ID=' . $this->photoId . ', 商品タイプ=' . self::PRODUCT_TYPE_DOWNLOAD);// 運用ログに記録
 			$isValidItem = false;
 		}
 
@@ -548,12 +556,12 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			// ダウンロード購入は複数購入不可
 			if ($cartItemQuantity == 0){
 				// カートに商品を追加
-				$ret = $ecLibObj->db->addProductToCart($cartSerial, $cartItemSerial, $cartId, self::PRODUCT_CLASS, $productId, self::PRODUCT_TYPE_DOWNLOAD, $this->_langId, 
+				$ret = $ecLibObj->db->addCartItem($cartSerial, $cartItemSerial, $cartId, self::PRODUCT_CLASS, $productId, self::PRODUCT_TYPE_DOWNLOAD, $this->_langId, 
 														$currency, $totalPrice, $quantity);
 			}
 		} else {
 			// カート商品の無効化
-			$ret = $ecLibObj->db->voidProductInCart($cartSerial, $cartItemSerial);
+			$ret = $ecLibObj->db->voidCartItem($cartSerial, $cartItemSerial);
 		}
 		// カート画面を表示
 		$cartPage = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=cart');
@@ -889,11 +897,12 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	 * 画像ID公開状況チェック
 	 *
 	 * @param string $photoId		画像ID
+	 * @param string $lang			言語ID
 	 * @return bool					true=公開中、false=非公開
 	 */
-	function isPublicPhotoId($photoId)
+	function isPublicPhotoId($photoId, $lang)
 	{
-		$ret = self::$_mainDb->getSearchPhotoInfo($photoId, $row, $categoryRows);
+		$ret = self::$_mainDb->getSearchPhotoInfo($photoId, $lang, $row, $categoryRows);
 		return $ret;
 	}
 	/**
