@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainDb.php 4393 2011-10-13 13:07:12Z fishbone $
+ * @version    SVN: $Id: photo_mainDb.php 4415 2011-10-23 13:45:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -18,7 +18,7 @@ require_once($gEnvManager->getDbPath() . '/baseDb.php');
 class photo_mainDb extends BaseDb
 {
 	/**
-	 * ブログ定義値を取得をすべて取得
+	 * フォトギャラリー定義値を取得をすべて取得
 	 *
 	 * @param array  $rows			レコード
 	 * @return bool					1行以上取得 = true, 取得なし= false
@@ -31,7 +31,7 @@ class photo_mainDb extends BaseDb
 		return $retValue;
 	}
 	/**
-	 * ブログ定義値を取得
+	 * フォトギャラリー定義値を取得
 	 *
 	 * @param string $key		キーとなる項目値
 	 * @return string $value	値
@@ -46,7 +46,7 @@ class photo_mainDb extends BaseDb
 		return $retValue;
 	}
 	/**
-	 * ブログ定義値を更新
+	 * フォトギャラリー定義値を更新
 	 *
 	 * @param string $key		キーとなる項目値
 	 * @param string $value		値
@@ -198,6 +198,19 @@ class photo_mainDb extends BaseDb
 		$queryStr .=   'WHERE ht_code = ? ';
 		return $this->isRecordExists($queryStr, array($code));
 	}
+	/**
+	 * 画像が存在するかチェック(言語に関わらず)
+	 *
+	 * @param string $publicId	画像ID
+	 * @return					true=存在する、false=存在しない
+	 */
+	function isExistsPhoto($publicId)
+	{
+		$queryStr  = 'SELECT * FROM photo ';
+		$queryStr .=   'WHERE ht_deleted = false ';
+		$queryStr .=     'AND ht_public_id = ? ';
+		return $this->isRecordExists($queryStr, array($publicId));
+	}
 	/**
 	 * 画像情報の新規追加、更新
 	 *
@@ -747,17 +760,19 @@ class photo_mainDb extends BaseDb
 	 * 画像情報を取得(公開用)
 	 *
 	 * @param string $filename		ファイル名
+	 * @param string $lang			言語ID
 	 * @param array $row			取得データ
 	 * @param array $categoryRows	画像カテゴリー
 	 * @return						true=正常、false=異常
 	 */
-	function getSearchPhotoInfo($filename, &$row, &$categoryRows = array())
+	function getSearchPhotoInfo($filename, $lang, &$row, &$categoryRows = array())
 	{
 		$queryStr  = 'SELECT * FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE ht_deleted = false ';
 		$queryStr .=     'AND ht_visible = true ';		// 公開中
 		$queryStr .=     'AND ht_public_id = ? ';
-		$ret = $this->selectRecord($queryStr, array($filename), $row);
+		$queryStr .=     'AND ht_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($filename, $lang), $row);
 		
 		if ($ret){
 			// 画像カテゴリー
@@ -805,5 +820,23 @@ class photo_mainDb extends BaseDb
 		$ret =$this->execStatement($queryStr, array($serial, $index, $categoryId));
 		return $ret;
 	}
+	/**
+	 * コンテンツ項目を外部用キーで取得
+	 *
+	 * @param string	$key				外部用キー
+	 * @param string	$langId				言語ID
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getContentByKey($key, $langId, &$row)
+	{
+		$queryStr  = 'SELECT * FROM content ';
+		$queryStr .=   'WHERE cn_deleted = false ';	// 削除されていない
+		$queryStr .=   'AND cn_type = ? ';
+		$queryStr .=   'AND cn_key = ? ';
+		$queryStr .=   'AND cn_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array(''/*デフォルトコンテンツ*/, $key, $langId), $row);
+		return $ret;
+	}
 }
 ?>
