@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: init.php 1098 2008-10-22 11:43:09Z fishbone $
+ * @version    SVN: $Id: init.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -303,9 +303,9 @@ if (isset($_GET['encode_hint']) && $_GET['encode_hint'] != '')
 // modified for Magic3 by naoki on 2008/9/26
 /*$arg = '';
 if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING']) {
-	$arg = & $_SERVER['QUERY_STRING'];
+	$arg = $_SERVER['QUERY_STRING'];
 } else if (isset($_SERVER['argv']) && ! empty($_SERVER['argv'])) {
-	$arg = & $_SERVER['argv'][0];
+	$arg = $_SERVER['argv'][0];
 }
 if (PKWK_QUERY_STRING_MAX && strlen($arg) > PKWK_QUERY_STRING_MAX) {
 	// Something nasty attack?
@@ -343,15 +343,15 @@ unset($matches);
 
 /////////////////////////////////////////////////
 // GET, POST, COOKIE
-$get    = & $_GET;
-$post   = & $_POST;
-$cookie = & $_COOKIE;
+$get    = $_GET;
+$post   = $_POST;
+$cookie = $_COOKIE;
 
 // GET + POST = $vars
 if (empty($_POST)) {
-	$vars = & $_GET;  // Major pattern: Read-only access via GET
+	$vars = $_GET;  // Major pattern: Read-only access via GET
 } else if (empty($_GET)) {
-	$vars = & $_POST; // Minor pattern: Write access via POST etc.
+	$vars = $_POST; // Minor pattern: Write access via POST etc.
 } else {
 	$vars = array_merge($_GET, $_POST); // Considered reliable than $_REQUEST
 }
